import { RendererFactory2 } from '@angular/core';
import { Observable } from 'rxjs';
import { NgxDynamicScriptLoaded, NgxDynamicScriptLoaderConfig, NgxDynamicScriptRef } from './ngx-dynamic-script-loader.config';
import * as i0 from "@angular/core";
/**
 * An Angular service to dynamically load and insert JavaScript modules into the DOM.
 * This service comes in handy in cases where a one wants to offset loading remote
 * JS modules from a CDN.
 *
 * @example
 * ...
 * ngOnInit() {
 *  const scriptRefs: ScriptRef[] = [
 *   {name: 'MyAwesomeScript', src: 'http://cdn.cloudflare.com/my-awesome-script.js'}
 *   {name: 'AnotherScript', src: 'http://cdn.cloudflare.com/another-script.js'}
 *  ];
 *
 *  // Load the first scriptRef
 *  this.dynamicScriptLoader
 *    .loadScript(scriptRefs[0])
 *    .subscribe((script) => {
 *      console.log(script);
 *      // Output: {name: "MyAwesomeScript", module: function () {}}
 *    });
 *
 *
 *  // Load both script refs
 *  this.dynamicScriptLoader
 *    .loadScript(...scriptRefs)
 *    .subscribe((scripts) => {
 *      console.log(scripts)
 *      // Output: [{name: "MyAwesomeScript", module: function() {}}, {name: "AnotherScript", module: function() {}}]
 *    })
 * }
 *
 *
 * @publicApi
 */
export declare class NgxDynamicScriptLoader {
    private readonly renderer2Factory;
    private readonly config;
    private doc;
    private readonly renderer2;
    private readonly scripts;
    /**
     * Initializes an Angular service that provides methods to fetch remote JS script files.
     *
     * @param {RendererFactory2} renderer2Factory Factory to create a custom render.
     * @param {Document} doc Main renderering context.
     */
    constructor(renderer2Factory: RendererFactory2, config: NgxDynamicScriptLoaderConfig, doc: Document);
    /**
     * Load a list of {@link NgxScriptRef} objects.
     * @param scriptRefs A list of script references to fetch.
     * @returns {Observable<NgxScriptLoaded[]>} An observable stream that when subscribed to emits
     *  the loaded script references.
     */
    loadScripts(...scriptRefs: NgxDynamicScriptRef[]): Observable<NgxDynamicScriptLoaded[]>;
    /**
     * Load a single {@link NgxScriptRef} object.
     * @param {NgxScriptRef} scriptRef Options to customize the script loading process.
     * @returns {Observable<NgxScriptLoaded>} Observable that when subscribed to emits the script object.
     */
    loadScript(scriptRef: NgxDynamicScriptRef): Observable<NgxDynamicScriptLoaded>;
    /**
     * Gets the {@link NgxDynamicScriptLoaded} by provided name if it exists - returns undefined otherwise.
     * @param {string} name The script's name to find.
     * @returns {NgxDynamicScriptLoaded | undefined} The script object if it exists, undefined otherwise.
     */
    get(name: string): NgxDynamicScriptLoaded | undefined;
    /**
     * Verify whether a script was already fetched and/or loaded from a remote server.
     * @param {string} name The name or url of the script to check.
     * @returns {boolean} Whether the script exists and the `loaded` property is set to true.
     */
    isLoaded(name: string): boolean;
    /**
     * Verify whether a script by provided name exists.
     * @param {string} name The script's name to check.
     * @returns {boolean} Whether script by provided name exist.
     */
    exists(name: string): boolean;
    private appendScript;
    private createScriptElement;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxDynamicScriptLoader, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NgxDynamicScriptLoader>;
}
